==> haskell-vector-builder-0.3.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-vector-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-builder
version: 0.3.1
id: vector-builder-0.3.1-HanlXD6nyUvA60lZKJcNL8
key: vector-builder-0.3.1-HanlXD6nyUvA60lZKJcNL8
license: MIT
copyright: (c) 2016, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/vector-builder
synopsis: Vector builder
description:
    An API for efficient and convenient construction of vectors.
    It provides the composable `Builder` abstraction, which has instances of the `Monoid` and `Semigroup` classes.
    .
    [Usage]
    .
    First you use the `Builder` abstraction to specify the structure of the vector.
    Then you execute the builder to actually produce the vector.
    .
    [Example]
    .
    The following code shows how you can efficiently concatenate different datastructures into a single immutable vector:
    .
    >
    >import qualified Data.Vector as A
    >import qualified VectorBuilder.Builder as B
    >import qualified VectorBuilder.Vector as C
    >
    >
    >myVector :: A.Vector a -> [a] -> a -> A.Vector a
    >myVector vector list element =
    >  C.build builder
    >  where
    >    builder =
    >      B.vector vector <>
    >      foldMap B.singleton list <>
    >      B.singleton element
category: Vector
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    VectorBuilder.Builder VectorBuilder.MVector VectorBuilder.Vector
hidden-modules: VectorBuilder.Private.Prelude
                VectorBuilder.Private.Action
                VectorBuilder.Private.SizeTrackingAction
                VectorBuilder.Private.Builder
abi: 15e9d9e4c9934985d9e0c0ea3c8a0e0b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/vector-builder-0.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/vector-builder-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/vector-builder-0.3.1
hs-libraries: HSvector-builder-0.3.1-HanlXD6nyUvA60lZKJcNL8
depends:
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT base-4.10.0.0
abi-depends: vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=be7241d647b311157e69b90e57b06d24
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-vector-builder/html/vector-builder.haddock
haddock-html: /usr/share/doc/haskell-vector-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-builder-0.3.3.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-vector-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-builder
version: 0.3.3.1
id: vector-builder-0.3.3.1-8YVAJrkDNXw3KWd9wBlvvK
key: vector-builder-0.3.3.1-8YVAJrkDNXw3KWd9wBlvvK
license: MIT
copyright: (c) 2016, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/vector-builder
synopsis: Vector builder
description:
    An API for efficient and convenient construction of vectors.
    It provides the composable `Builder` abstraction, which has instances of the `Monoid` and `Semigroup` classes.
    .
    [Usage]
    .
    First you use the `Builder` abstraction to specify the structure of the vector.
    Then you execute the builder to actually produce the vector.
    .
    [Example]
    .
    The following code shows how you can efficiently concatenate different datastructures into a single immutable vector:
    .
    >
    >import qualified Data.Vector as A
    >import qualified VectorBuilder.Builder as B
    >import qualified VectorBuilder.Vector as C
    >
    >
    >myVector :: A.Vector a -> [a] -> a -> A.Vector a
    >myVector vector list element =
    >  C.build builder
    >  where
    >    builder =
    >      B.vector vector <>
    >      foldMap B.singleton list <>
    >      B.singleton element
category: Vector
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    VectorBuilder.Builder VectorBuilder.MVector VectorBuilder.Vector
hidden-modules: VectorBuilder.Private.Prelude
                VectorBuilder.Private.Update VectorBuilder.Private.Builder
abi: b64970af47556a87f35d03954a9270d9
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/vector-builder-0.3.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/vector-builder-0.3.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/vector-builder-0.3.3.1
hs-libraries: HSvector-builder-0.3.3.1-8YVAJrkDNXw3KWd9wBlvvK
depends:
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT base-4.10.0.0
abi-depends: vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=be7241d647b311157e69b90e57b06d24
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-vector-builder/html/vector-builder.haddock
haddock-html: /usr/share/doc/haskell-vector-builder/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
